"use strict";Object.defineProperty(exports, "__esModule", { value: true });var _createClass = function () {function defineProperties(target, props) {for (var i = 0; i < props.length; i++) {var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);}}return function (Constructor, protoProps, staticProps) {if (protoProps) defineProperties(Constructor.prototype, protoProps);if (staticProps) defineProperties(Constructor, staticProps);return Constructor;};}();var _ApiClient = require("./ApiClient");var _ApiClient2 = _interopRequireDefault(_ApiClient);

var _applyTemplate2 = require("./command/applyTemplate");var _applyTemplate3 = _interopRequireDefault(_applyTemplate2);
var _deployManifest2 = require("./command/deployManifest");var _deployManifest3 = _interopRequireDefault(_deployManifest2);
var _deployProxy2 = require("./command/deployProxy");var _deployProxy3 = _interopRequireDefault(_deployProxy2);
var _downloadProxy2 = require("./command/downloadProxy");var _downloadProxy3 = _interopRequireDefault(_downloadProxy2);
var _extractTemplate2 = require("./command/extractTemplate");var _extractTemplate3 = _interopRequireDefault(_extractTemplate2);
var _packageManifest2 = require("./command/packageManifest");var _packageManifest3 = _interopRequireDefault(_packageManifest2);
var _packageProxy2 = require("./command/packageProxy");var _packageProxy3 = _interopRequireDefault(_packageProxy2);
var _updateMap2 = require("./command/updateMap");var _updateMap3 = _interopRequireDefault(_updateMap2);
var _uploadProxy2 = require("./command/uploadProxy");var _uploadProxy3 = _interopRequireDefault(_uploadProxy2);function _interopRequireDefault(obj) {return obj && obj.__esModule ? obj : { default: obj };}function _classCallCheck(instance, Constructor) {if (!(instance instanceof Constructor)) {throw new TypeError("Cannot call a class as a function");}}

/**
                                                                                                                                                                                                                                                                                                                                                                   * @typedef {object} Configuration
                                                                                                                                                                                                                                                                                                                                                                   * @description An object for configuring the API manager tools.
                                                                                                                                                                                                                                                                                                                                                                   * @property {string} username The API Portal username used for authentication.
                                                                                                                                                                                                                                                                                                                                                                   * @property {string} password The password for the above user.
                                                                                                                                                                                                                                                                                                                                                                   * @property {string} host The hostname of the API Portal.
                                                                                                                                                                                                                                                                                                                                                                   * @property {string=} proxy Optional (https) proxy server URI.
                                                                                                                                                                                                                                                                                                                                                                   */

/**
                                                                                                                                                                                                                                                                                                                                                                       * Public API class for the library.
                                                                                                                                                                                                                                                                                                                                                                       * @class
                                                                                                                                                                                                                                                                                                                                                                       */var
ApiManager = function () {
  /**
                           * Builds a new API Manager toolset class.
                           * @constructor
                           * @param {Configuration} config
                           */
  function ApiManager(config) {_classCallCheck(this, ApiManager);
    this.client = new _ApiClient2.default(config);
    this.config = config;
  }

  /**
     * Applies the given placeholder values to the template.
     * @param {string} source A directory where the template files are located.
     * @param {string} target The target directory (if it does not exist, it is created).
     * @param {object} placeholders A map between the placeholder names and values (as strings).
     * @param {boolean} [clean=false] Flag indicating if the target directory should be cleaned.
     * @returns {Promise} A promise that is resolved when the operation has finised.
     */_createClass(ApiManager, [{ key: "applyTemplate", value: function applyTemplate(
    source, target, placeholders) {var clean = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
      return (0, _applyTemplate3.default)(source, target, placeholders, clean);
    }

    /**
       * Deploys the API manager artifacts described in the given manifest.
       * @param {string} path The absolute or relative path of the manifest file.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "deployManifest", value: function deployManifest(
    path) {
      return (0, _deployManifest3.default)(this.client, path);
    }

    /**
       * Deploys all the manifests matching the given glob pattern.
       * @param {string} pattern A glob pattern.
       * @param {boolean} [force=false] If true, the method continues execution even if one
       *  manifest deployment fails.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "deployManifestsMatching", value: function deployManifestsMatching(
    pattern) {var force = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      return (0, _deployManifest2.deployManifestsMatching)(this.client, pattern, force);
    }

    /**
       * Deploys the API manager proxy files located in the given directory.
       * @param {string} path The absolute or relative path of the directory.
       * @param {boolean} [templated=false] Flag indicating if the files are part of a template.
       * @param {object} [placeholders={}] A map between the placeholder names and values (as
       *  strings). Only relevant if templated is set to true.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "deployProxy", value: function deployProxy(
    path) {var templated = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;var placeholders = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      return (0, _deployProxy3.default)(this.client, path, templated, placeholders);
    }

    /**
       * Downloads an existing API Proxy from the API Portal.
       * @param {string} name The name of the existing API proxy.
       * @param {string} path A directory where the results will be stored (if it does not exist,
       *  it is created).
       * @param {boolean} [clean=false] Flag indicating if the target directory should be cleaned.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "downloadProxy", value: function downloadProxy(
    name, path) {var clean = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
      return (0, _downloadProxy3.default)(this.client, name, path, clean);
    }

    /**
       * Extracts ("reverse-engineers") a template from existing proxy files.
       * @param {string} source A directory where the source files are located.
       * @param {string} target A directory where the results will be stored (if it does not exist,
       *  it is created).
       * @param {object} placeholders A map between the placeholder names and values.
       * @param {boolean} [clean=false] Flag indicating if the target directory should be cleaned.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "extractTemplate", value: function extractTemplate(
    source, target, placeholders) {var clean = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
      return (0, _extractTemplate3.default)(source, target, placeholders, clean);
    }

    /**
       * Extracts ("reverse-engineers") a template from existing deployed API proxy.
       * @param {string} manifestPath The path to the manifest describing the API proxy.
       * @param {string} target A directory where the results will be stored (if it does not exist,
       *  it is created).
       * @param {boolean} [clean=false] Flag indicating if the target directory should be cleaned.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "extractTemplateFromManifest", value: function extractTemplateFromManifest(
    manifestPath, target) {var clean = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
      return (0, _extractTemplate2.extractTemplateFromManifest)(this.client, manifestPath, target, clean);
    }

    /**
       * Returns the configured API Manager host.
       * @returns {string} The host of the API Manager.
       */ }, { key: "getConfiguredHost", value: function getConfiguredHost()
    {
      return this.config.host;
    }

    /**
       * Packages an API proxy described by the given manifest into an archive.
       * @param {string} manifestPath The path to the manifest describing the API proxy.
       * @param {string} target The path (including the filename) where to store the zip file.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "packageManifest", value: function packageManifest(
    manifestPath, target) {
      return (0, _packageManifest3.default)(manifestPath, target);
    }

    /**
       * Packages all the manifests matched by the given glob pattern.
       * @param {string} pattern The glob pattern to be expanded.
       * @param {boolean} [force=false] If true, the method continues execution even if one
       *  operation fails.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "packageManifestsMatching", value: function packageManifestsMatching(
    pattern) {var force = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      return (0, _packageManifest2.packageManifestsMatching)(pattern, force);
    }

    /**
       * Packages the API proxy files located at the given directory into a zip stream.
       * @param {string} path The path to the directory containing the proxy files.
       * @param {boolean} [templated=false] Flag indicating if the files are part of a template.
       * @param {object} [placeholders={}] A map between the placeholder names and values (as
       *  strings). Only relevant if templated is set to true.
       * @returns {Promise} A promise that is resolved when the operation has finised. The
       *  Promise will return a stream containing the zip archive when resolved.
       */ }, { key: "packageProxy", value: function packageProxy(
    path) {var templated = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;var placeholders = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      return (0, _packageProxy3.default)(path, templated, placeholders);
    }

    /**
       * Packages the API proxy files located at the given directory into a zip file.
       * @param {string} path The path to the directory containing the proxy files.
       * @param {string} target The path (including the filename) where to store the zip file.
       * @param {boolean} [templated=false] Flag indicating if the files are part of a template.
       * @param {object} [placeholders={}] A map between the placeholder names and values (as
       *  strings). Only relevant if templated is set to true.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "packageProxyToFile", value: function packageProxyToFile(
    path, target) {var templated = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;var placeholders = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
      return (0, _packageProxy2.packageProxyToFile)(path, target, templated, placeholders);
    }

    /**
       * Update a key-value map on the API Manager. If the map does not exist, it is created.
       * @param {string} name The name of the key-value map.
       * @param {object} keys A map between the keys and the values. If a given value is
       *  a string, then it is sent as-is to the API Manager. Otherwise, it is serialized
       *  into JSON.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "updateMap", value: function updateMap(
    name, keys) {
      return (0, _updateMap3.default)(this.client, name, keys);
    }
    /**
       * Updates several key-value maps on the API Manager.
       * @see updateMap
       * @param {object} maps A map between the key-value map name and the keys.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "updateMapsFromObject", value: function updateMapsFromObject(
    maps) {
      return (0, _updateMap2.updateMapsFromObject)(this.client, maps);
    }

    /**
       * Uploads an API Proxy archive to the API Portal.
       * @param {string|stream} pathOrStream Either the path to a zip file or a stream
       *  containing the archive.
       * @returns {Promise} A promise that is resolved when the operation has finised.
       */ }, { key: "uploadProxy", value: function uploadProxy(
    pathOrStream) {
      return (0, _uploadProxy3.default)(this.client, pathOrStream);
    } }]);return ApiManager;}();exports.default =


ApiManager;