#!/usr/bin/env node
"use strict";

var _index = require("./index");var _index2 = _interopRequireDefault(_index);
var _commander = require("commander");var _commander2 = _interopRequireDefault(_commander);
var _prompt = require("prompt");var _prompt2 = _interopRequireDefault(_prompt);
var _package = require("../package.json");

var _logger = require("./logger");var _logger2 = _interopRequireDefault(_logger);function _interopRequireDefault(obj) {return obj && obj.__esModule ? obj : { default: obj };}

function wrapAction(cb) {
    return function () {
        if (_commander2.default.silent) {
            _logger2.default.level = _logger.LOG_LEVEL.SILENT;
        } else if (_commander2.default.debug) {
            _logger2.default.level = _logger.LOG_LEVEL.DEBUG;
        }
        try {for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {args[_key] = arguments[_key];}
            var promise = cb.apply(null, args);
            if (promise && promise.catch) {
                promise.catch(function (e) {return _logger2.default.error("Operation failed with error: " + e.toString());});
            }
        } catch (e) {
            _logger2.default.error("Operation failed with error: " + e.toString());
            process.exitCode = 1;
        }
    };
}

function extractPlaceholders(ph) {
    var placeholders = {};
    for (var i = 0; i < ph.length; ++i) {
        var single = (ph[i] || "").split("=");
        if (single.length === 2) {
            placeholders[single[0].trim()] = single[1].trim();
        }
    }
    return placeholders;
}

_commander2.default.name(_package.name).
version(_package.version, "-v, --version").
description(_package.description).
option("-s, --silent", "suppress console output").
option("-d, --debug", "show debug messages");

_commander2.default.command("apply-template <source_directory> <target_directory> [placeholders...]").
description("applies a template by replacing the given placeholders").
option("-c, --clean", "clean the target directory first").
action(wrapAction(function (source, target, ph, options) {return (
        (0, _index2.default)().applyTemplate(source, target, extractPlaceholders(ph), options.clean));}));

_commander2.default.command("deploy <manifest>").
description("deploy API manager artifacts described by the given manifest").
action(wrapAction(function (manifest) {return (0, _index2.default)().deployManifest(manifest);}));

_commander2.default.command("deploy-all <pattern>").
description("deploy all the manifests matching the given glob pattern").
option("-f, --force", "continues execution even if one manifest deployment fails").
action(wrapAction(function (pattern, options) {return (0, _index2.default)().deployManifestsMatching(pattern, options.force);}));

_commander2.default.command("deploy-proxy <directory> [placeholders...]").
description("deploy the API proxy located in the given directory").
action(wrapAction(function (path, ph) {return ph.length > 0 ?
    (0, _index2.default)().deployProxy(path, true, extractPlaceholders(ph)) : (0, _index2.default)().deployProxy(path);}));

_commander2.default.command("download-proxy <proxy_name> <target_directory>").
description("download an already existing API proxy from the API Portal").
option("-c, --clean", "clean the target directory first").
action(wrapAction(function (name, target, options) {return (0, _index2.default)().downloadProxy(name, target, options.clean);}));

_commander2.default.command("extract-template-proxy <source> <target> [placeholders...]").
description("extract a template from an existing API proxy").
option("-c, --clean", "clean the target directory first").
action(wrapAction(function (source, target, ph, options) {return (
        (0, _index2.default)().extractTemplate(source, target, extractPlaceholders(ph), options.clean));}));

_commander2.default.command("extract-template <manifest> [target_directory]").
description("extract a template from an already deployed proxy (described by the given manifest)").
option("-c, --clean", "clean the target directory first").
action(wrapAction(function (manifest, target, options) {return (
        (0, _index2.default)().extractTemplateFromManifest(manifest, target, options.clean));}));

_commander2.default.command("package <manifest> [target_archive]").
description("package the API proxy described by the given manifest into an archive").
action(wrapAction(function (path, target) {return (0, _index2.default)().packageManifest(path, target);}));

_commander2.default.command("package-all <pattern>").
description("package all the API proxies described by the manifests matched by the given pattern").
option("-f, --force", "continues execution even if one operation fails").
action(wrapAction(function (path, options) {return (0, _index2.default)().packageManifestsMatching(path, options.force);}));

_commander2.default.command("package-proxy <directory> <target_archive> [placeholders...]").
description("package the proxy located in the given directory").
action(wrapAction(function (path, target, ph) {return ph.length > 0 ?
    (0, _index2.default)().packageProxyToFile(path, target, true, extractPlaceholders(ph)) :
    (0, _index2.default)().packageProxyToFile(path, target);}));

_commander2.default.command("upload-proxy <archive>").
description("upload an API proxy as an archive to the API Portal").
action(wrapAction(function (path) {return (0, _index2.default)().uploadProxy(path);}));

_commander2.default.command("config").
description("configure the sapim library (create a .sapim file)").
option("-g, --global", "creates the file globally (in the home dir)").
option("-f, --force", "overwrites any existing configuration").
action(wrapAction(function (options) {
    _prompt2.default.start({ message: "" });
    return new Promise(function (resolve, reject) {
        _prompt2.default.get({
            properties: {
                host: {
                    description: "API portal hostname",
                    required: true },

                username: {
                    description: "API portal username",
                    required: true },

                password: {
                    description: "API portal password",
                    hidden: true,
                    required: true },

                proxy: {
                    description: "HTTPS proxy (optional)",
                    required: false } } },


        function (err, result) {
            if (err) {
                reject(err);
            } else {
                resolve(result);
            }
        });
    }).then(function (content) {return (0, _index.createConfigFile)(content, options.global, options.force);});
}));

_commander2.default.parse(process.argv);